'
'FMOD VB6 Module
'

  Const FMOD_VERSION = 3.7

'************
'* Enums
'************
'FSOUND_GetError
CONST FMOD_ERR_NONE = 0            ' No errors
CONST FMOD_ERR_BUSY = 1            ' Cannot call this command after FSOUND_Init.  Call FSOUND_Close first.
CONST FMOD_ERR_UNINITIALIZED = 2   ' This command failed because FSOUND_Init was not called
CONST FMOD_ERR_INIT = 3            ' Error initializing output device.
CONST FMOD_ERR_ALLOCATED = 4       ' Error initializing output device, but more specifically, the output device is already in use and cannot be reused.
CONST FMOD_ERR_PLAY = 5            ' Playing the sound failed.
CONST FMOD_ERR_OUTPUT_FORMAT = 6   ' Soundcard does not support the features needed for this soundsystem (16bit stereo output)
CONST FMOD_ERR_COOPERATIVELEVEL = 7 ' Error setting cooperative level for hardware.
CONST FMOD_ERR_CREATEBUFFER = 8    ' Error creating hardware sound buffer.
CONST FMOD_ERR_FILE_NOTFOUND = 9   ' File not found
CONST FMOD_ERR_FILE_FORMAT = 10     ' Unknown file format
CONST FMOD_ERR_FILE_BAD = 11        ' Error loading file
CONST FMOD_ERR_MEMORY = 12          ' Not enough memory
CONST FMOD_ERR_VERSION = 13         ' The version number of this file format is not supported
CONST FMOD_ERR_INVALID_MIXER = 14   ' Incorrect mixer selected
CONST FMOD_ERR_INVALID_PARAM = 15   ' An invalid parameter was passed to this FUNCTION
CONST FMOD_ERR_NO_EAX = 16          ' Tried to use an EAX command on a non EAX enabled channel or output.
CONST FMOD_ERR_NO_EAX2 = 17         ' Tried to use an advanced EAX2 command on a non EAX2 enabled channel or output.
CONST FMOD_ERR_CHANNEL_ALLOC = 18   ' Failed to allocate a new channel
CONST FMOD_ERR_RECORD = 19        ' Recording is not supported on this machine
CONST FMOD_ERR_MEDIAPLAYER = 20     ' Windows Media Player not installed so cannot play wma or use internet streaming.
CONST FMOD_ERR_CDDEVICE = 21        ' An error occured trying to open the specified CD device


' FMOD_ERRORS
' On failure of commands in FMOD, use FSOUND_GetError to attain what happened.
'


' FSOUND_OUTPUTTYPES
' These output types are used with FSOUND_SetOutput, to choose which output driver to use.
' FSOUND_OUTPUT_DSOUND will not support hardware 3d acceleration if the sound card driver
' does not support DirectX 6 Voice Manager Extensions.
' FSOUND_OUTPUT_WINMM is recommended for NT and CE.
'
'FSOUND_SetOutput, FSOUND_GetOutput
CONST FSOUND_OUTPUT_NOSOUND = 0    'NoSound driver, all calls to this succeed but do nothing.
CONST FSOUND_OUTPUT_WINMM = 1     'Windows Multimedia driver.
CONST FSOUND_OUTPUT_DSOUND = 2    'DirectSound driver.  You need this to get EAX or EAX2 support.
CONST FSOUND_OUTPUT_A3D = 3       'A3D driver.  You need this to get geometry and EAX reverb support.
       ' A3D driver.

    'FSOUND_OUTPUT_OSS       ' Linux/Unix OSS (Open Sound System) driver, i.e. the kernel sound drivers.
    'FSOUND_OUTPUT_ESD       ' Linux/Unix ESD (Enlightment Sound Daemon) driver.
    'FSOUND_OUTPUT_ALSA      ' Linux Alsa driver.

    'FSOUND_OUTPUT_ASIO      ' Low latency ASIO driver
    'FSOUND_OUTPUT_XBOX      ' Xbox driver
    'FSOUND_OUTPUT_PS2       ' PlayStation 2 driver
    'FSOUND_OUTPUT_MAC       ' Mac SoundMager driver
    'FSOUND_OUTPUT_GC        ' Gamecube driver

    'FSOUND_OUTPUT_NOSOUND_NONREALTIME  ' This is the same as nosound, but the sound generation is driven by FSOUND_Update



' FSOUND_MIXERTYPES
' These mixer types are used with FSOUND_SetMixer, to choose which mixer to use, or to act
' upon for other reasons using FSOUND_GetMixer.
' It is not nescessary to set the mixer.  FMOD will autodetect the best mixer for you.
'
CONST FSOUND_MIXER_QUALITY_AUTODETECT = 0'All platforms - This enables autodetection of the fastest quality mixer based on your cpu.
CONST FSOUND_MIXER_QUALITY_FPU = 1       'This enables the interpolating FPU mixer.Win32/Linux only - Interpolating/volume ramping FPU mixer.
CONST FSOUND_MIXER_QUALITY_MMXP5 = 2      'This enables the interpolating p5 MMX mixer.Win32/Linux only - Interpolating/volume ramping FPU mixer.
CONST FSOUND_MIXER_QUALITY_MMXP6 = 3     'This enables the interpolating ppro/p2/p3 MMX mixer.Win32/Linux only - Interpolating/volume ramping ppro+ MMX mixer.

    'FSOUND_MIXER_AUTODETECT         ' CE/PS2 Only - Non interpolating/low quality mixer
    'FSOUND_MIXER_BLENDMODE          ' removed / obsolete.
    'FSOUND_MIXER_MMXP5              ' removed / obsolete.
    'FSOUND_MIXER_MMXP6              ' removed / obsolete.

    
    'FSOUND_MIXER_MONO               ' CE/PS2 only - MONO non interpolating/low quality mixer. For speed
    'FSOUND_MIXER_QUALITY_MONO       ' CE/PS2 only - MONO Interpolating mixer.  For speed



' FMUSIC_TYPES
' These definitions describe the type of song being played.
' See FMUSIC_GetType
'
'FMUSIC_GetType
CONST FMUSIC_TYPE_NONE = 0
CONST FMUSIC_TYPE_MOD = 1       'Protracker / Fasttracker
CONST FMUSIC_TYPE_S3M = 2       'ScreamTracker 3
CONST FMUSIC_TYPE_XM = 3        'FastTracker 2
CONST FMUSIC_TYPE_IT = 4        'Impulse Tracker.
'  voir
CONST FMUSIC_TYPE_MIDI = 5       'MIDI file
CONST FMUSIC_TYPE_FSB  = 6       'FMOD Sample Bank file



' FSOUND_DSP_PRIORITIES
' These default priorities are used by FMOD internal system DSP units.  They describe the
' position of the DSP chain, and the order of how audio processing is executed.
' You can actually through the use of FSOUND_DSP_GetxxxUnit (where xxx is the name of the DSP
' unit), disable or even change the priority of a DSP unit.
'
  'FSOUND_DSP_PRIORITIES
    Const FSOUND_DSP_DEFAULTPRIORITY_CLEARUNIT = 0           'DSP CLEAR unit - done first
    Const FSOUND_DSP_DEFAULTPRIORITY_SFXUNIT = 100           'DSP SFX unit - done second
    Const FSOUND_DSP_DEFAULTPRIORITY_MUSICUNIT = 200         'DSP MUSIC unit - done third
    Const FSOUND_DSP_DEFAULTPRIORITY_USER = 300              'User priority, use this as reference for your own dsp units
    Const FSOUND_DSP_DEFAULTPRIORITY_FFTUNIT = 900           'This reads data for FSOUND_DSP_GetSpectrum, so it comes after user units
    Const FSOUND_DSP_DEFAULTPRIORITY_CLIPANDCOPYUNIT = 1000  'DSP CLIP AND COPY unit - last



' FSOUND_CAPS
' Driver description bitfields.  Use FSOUND_Driver_GetCaps to determine if a driver enumerated
' has the settings you are after.  The enumerated driver depends on the output mode, see
' FSOUND_OUTPUTTYPES
'
  'FSOUND_CAPS
    Const FSOUND_CAPS_HARDWARE = &H1       ' This driver supports hardware accelerated 3d sound.
    Const FSOUND_CAPS_EAX2 = &H2           ' This driver supports EAX 2 reverb
    Const FSOUND_CAPS_EAX3 = &H10          ' This driver supports EAX 3 reverb



' FSOUND_MODES
' Sample description bitfields, OR them together for loading and describing samples.
' NOTE.  If the file format being loaded already has a defined format, such as WAV or MP3, then
' trying to override the pre-defined format with a new set of format flags will not work.  For
' example, an 8 bit WAV file will not load as 16bit if you specify FSOUND_16BITS.  It will just
' ignore the flag and go ahead loading it as 8bits.  For these type of formats the only flags
' you can specify that will really alter the behaviour of how it is loaded, are the following.
'
' FSOUND_LOOP_OFF
' FSOUND_LOOP_NORMAL
' FSOUND_LOOP_BIDI
' FSOUND_HW3D
' FSOUND_2D
' FSOUND_STREAMABLE
' FSOUND_LOADMEMORY
' FSOUND_LOADRAW
' FSOUND_MPEGACCURATE
'
' See flag descriptions for what these do.
'
  'FSOUND_MODES
    Const FSOUND_LOOP_OFF = &H1             ' For non looping samples.
    Const FSOUND_LOOP_NORMAL = &H2          ' For forward looping samples.
    Const FSOUND_LOOP_BIDI = &H4            ' For bidirectional looping samples.  (no effect if in hardware).
    Const FSOUND_8BITS = &H8                ' For 8 bit samples.
    Const FSOUND_16BITS = &H10              ' For 16 bit samples.
    Const FSOUND_MONO = &H20                ' For mono samples.
    Const FSOUND_STEREO = &H40              ' For stereo samples.
    Const FSOUND_UNSIGNED = &H80            ' For source data containing unsigned samples.
    Const FSOUND_SIGNED = &H100             ' For source data containing signed data.
    Const FSOUND_DELTA = &H200              ' For source data stored as delta values.
    Const FSOUND_IT214 = &H400              ' For source data stored using IT214 compression.
    Const FSOUND_IT215 = &H800              ' For source data stored using IT215 compression.
    Const FSOUND_HW3D = &H1000              ' Attempts to make samples use 3d hardware acceleration. (if the card supports it)
    Const FSOUND_2D = &H2000                ' Ignores any 3d processing.  overrides FSOUND_HW3D.  Located in software.
    Const FSOUND_STREAMABLE = &H4000        ' For realtime streamable samples.  If you dont supply this sound may come out corrupted.
    Const FSOUND_LOADMEMORY = &H8000        ' For FSOUND_Sample_Load - name will be interpreted as a pointer to data
    Const FSOUND_LOADRAW = &H10000          ' For FSOUND_Sample_Load/FSOUND_Stream_Open - will ignore file format and treat as raw pcm.
    Const FSOUND_MPEGACCURATE = &H20000     ' For FSOUND_Stream_Open - scans MP2/MP3 (VBR also) for accurate FSOUND_Stream_GetLengthMs/FSOUND_Stream_SetTime.
    Const FSOUND_FORCEMONO = &H40000        ' For forcing stereo streams and samples to be mono - needed with FSOUND_HW3D - incurs speed hit
    Const FSOUND_HW2D = &H80000             ' 2d hardware sounds.  allows hardware specific effects
    Const FSOUND_ENABLEFX = &H100000        ' Allows DX8 FX to be played back on a sound.  Requires DirectX 8 - Note these sounds cant be played more than once, or have a changing frequency
    Const FSOUND_MPEGHALFRATE = &H200000    ' For FMODCE only - decodes mpeg streams using a lower quality decode, but faster execution
    'Const FSOUND_XADPCM = &H400000          ' For XBOX only - Describes a user sample that its contents are compressed as XADPCM
    'Const FSOUND_VAG = &H800000             ' For PS2 only - Describes a user sample that its contents are compressed as Sony VAG format.
    Const FSOUND_NONBLOCKING = &H1000000    ' For FSOUND_Stream_Open - Causes stream to open in the background and not block the foreground app - stream plays only when ready.
    'Const FSOUND_GCADPCM = &H2000000        ' For Gamecube only - Contents are compressed as Gamecube DSP-ADPCM format
    'Const FSOUND_MULTICHANNEL = &H4000000   ' For PS2 only - Contents are interleaved into a multi-channel (more than stereo) format
    'Const FSOUND_USECORE0 = &H8000000       ' For PS2 only - Sample/Stream is forced to use hardware voices 00-23
    'Const FSOUND_USECORE1 = &H10000000      ' For PS2 only - Sample/Stream is forced to use hardware voices 24-47
    'Const FSOUND_LOADMEMORYIOP = &H20000000 ' For PS2 only - "name" will be interpreted as a pointer to data for streaming and samples.  The address provided will be an IOP address
    Const FSOUND_STREAM_NET = &H80000000    ' Specifies an internet stream
    
    Const FSOUND_NORMAL = FSOUND_16BITS Or FSOUND_SIGNED Or FSOUND_MONO



' FSOUND_CDPLAYMODES
' Playback method for a CD Audio track, with FSOUND_CD_SetPlayMode
'
  'FSOUND_CDPLAYMODES
    Const FSOUND_CD_PLAYCONTINUOUS = 1       'Starts from the current track and plays to end of CD.
    Const FSOUND_CD_PLAYONCE       = 2        'Plays the specified track then stops.
    Const FSOUND_CD_PLAYLOOPED     = 3        'Plays the specified track looped, forever until stopped manually.
    Const FSOUND_CD_PLAYRANDOM     = 4        'Plays tracks in random order



' FSOUND_CHANNELSAMPLEMODE
' Miscellaneous values for FMOD functions.
' FSOUND_PlaySound, FSOUND_PlaySoundEx, FSOUND_Sample_Alloc, FSOUND_Sample_Load, FSOUND_SetPan
'
  'FSOUND_CHANNELSAMPLEMODE
    Const FSOUND_FREE = -1                 ' definition for dynamically allocated channel or sample
    Const FSOUND_UNMANAGED = -2            ' definition for allocating a sample that is NOT managed by fsound
    Const FSOUND_ALL = -3                  ' for a channel index or sample index, this flag affects ALL channels or samples available!  Not supported by all functions.
    Const FSOUND_STEREOPAN = -1            ' definition for full middle stereo volume on both channels
    Const FSOUND_SYSTEMCHANNEL = -1000     ' special channel ID for channel based functions that want to alter the global FSOUND software mixing output channel
    Const FSOUND_SYSTEMSAMPLE = -1000      ' special sample ID for all sample based functions that want to alter the global FSOUND software mixing output sample



' FSOUND_REVERB_PROPERTIES
' FSOUND_Reverb_SetProperties, FSOUND_Reverb_GetProperties, FSOUND_REVERB_PROPERTYFLAGS
'

  Type FSOUND_REVERB_PROPERTIES
                                    ' MIN     MAX    DEFAULT DESCRIPTION
    Environment         As Long     ' 0       25     0       sets all listener properties
    EnvSize             As long   ' 1.0     100.0  7.5     environment size in meters
    EnvDiffusion        As long   ' 0.0     1.0    1.0     environment diffusion
    Room                As Long     ' -10000  0      -1000   room effect level (at mid frequencies)
    RoomHF              As Long     ' -10000  0      -100    relative room effect level at high frequencies
    RoomLF              As Long     ' -10000  0      0       relative room effect level at low frequencies
    DecayTime           As long   ' 0.1     20.0   1.49    reverberation decay time at mid frequencies
    DecayHFRatio        As long   ' 0.1     2.0    0.83    high-frequency to mid-frequency decay time ratio
    DecayLFRatio        As long   ' 0.1     2.0    1.0     low-frequency to mid-frequency decay time ratio
    Reflections         As Long     ' -10000  1000   -2602   early reflections level relative to room effect
    ReflectionsDelay    As long   ' 0.0     0.3    0.007   initial reflection delay time
    ReflectionsPan(3)   As long   '                0,0,0   early reflections panning vector
    Reverb              As Long     ' -1000   2000   200     late reverberation level relative to room effect
    ReverbDelay         As long   ' 0.0     0.1    0.011   late reverberation delay time relative to initial reflection
    ReverbPan(3)        As long   '                0,0,0   late reverberation panning vector
    EchoTime            As long   ' .075    0.25   0.25    echo time
    EchoDepth           As long   ' 0.0     1.0    0.0     echo depth
    ModulationTime      As long   ' 0.04    4.0    0.25    modulation time
    ModulationDepth     As long   ' 0.0     1.0    0.0     modulation depth
    AirAbsorptionHF     As long   ' -100    0.0    -5.0    change in level per meter at high frequencies
    HFReference         As long   ' 1000.0  20000  5000.0  reference high frequency (hz)
    LFReference         As long   ' 20.0    1000.0 250.0   reference low frequency (hz)
    RoomRolloffFactor   As long   ' 0.0     10.0   0.0     like FSOUND_3D_SetRolloffFactor but for room effect
    Diffusion           As long   ' 0.0     100.0  100.0   Value that controls the echo density in the late reverberation decay. (xbox only)
    Density             As long   ' 0.0     100.0  100.0   Value that controls the modal density in the late reverberation decay (xbox only)
    flags               As Long     '                        modifies the behavior of above properties
End Type


' FSOUND_REVERB_FLAGS
' Values for the Flags member of the FSOUND_REVERB_PROPERTIES structure.
'
  'FSOUND_REVERB_PROPERTYFLAGS
    Const FSOUND_REVERBFLAGS_DECAYTIMESCALE = &H1          ' EnvironmentSize affects reverberation decay time
    Const FSOUND_REVERBFLAGS_REFLECTIONSSCALE = &H2        ' EnvironmentSize affects reflection level
    Const FSOUND_REVERBFLAGS_REFLECTIONSDELAYSCALE = &H4   ' EnvironmentSize affects initial reflection delay time
    Const FSOUND_REVERBFLAGS_REVERBSCALE = &H8             ' EnvironmentSize affects reflections level
    Const FSOUND_REVERBFLAGS_REVERBDELAYSCALE = &H10       ' EnvironmentSize affects late reverberation delay time
    Const FSOUND_REVERBFLAGS_DECAYHFLIMIT = &H20           ' AirAbsorptionHF affects DecayHFRatio
    Const FSOUND_REVERBFLAGS_ECHOTIMESCALE = &H40          ' EnvironmentSize affects echo time
    Const FSOUND_REVERBFLAGS_MODULATIONTIMESCALE = &H80    ' EnvironmentSize affects modulation time
    'Const FSOUND_REVERB_FLAGS_CORE0 = &H100                ' PS2 Only - Reverb is applied to CORE0 (hw voices 0-23)
    'Const FSOUND_REVERB_FLAGS_CORE1 = &H200                ' PS2 Only - Reverb is applied to CORE1 (hw voices 24-47)
    Const FSOUND_REVERBFLAGS_DEFAULT = FSOUND_REVERBFLAGS_DECAYTIMESCALE Or FSOUND_REVERBFLAGS_REFLECTIONSSCALE Or FSOUND_REVERBFLAGS_REFLECTIONSDELAYSCALE Or FSOUND_REVERBFLAGS_REVERBSCALE Or FSOUND_REVERBFLAGS_REVERBDELAYSCALE Or FSOUND_REVERBFLAGS_DECAYHFLIMIT Or FSOUND_REVERB_FLAGS_CORE0 Or FSOUND_REVERB_FLAGS_CORE1



' FSOUND_REVERB_CHANNELPROPERTIES
' Structure defining the properties for a reverb source, related to a FSOUND channel.
' FSOUND_Reverb_SetEnvironment, FSOUND_Reverb_SetEnvironmentAdvanced
'
  Type FSOUND_REVERB_CHANNELPROPERTIES
    Direct               As Long     ' direct path level (at low and mid frequencies)
    DirectHF             As Long     ' relative direct path level at high frequencies
    Room                 As Long     ' room effect level (at low and mid frequencies)
    RoomHF               As Long     ' relative room effect level at high frequencies
    Obstruction          As Long     ' main obstruction control (attenuation at high frequencies)
    ObstructionLFRatio   As long   ' obstruction low-frequency level re. main control
    Occlusion            As Long     ' main occlusion control (attenuation at high frequencies)
    OcclustionLFRatio    As long   ' occlusion low-frequency level re. main control
    OcclusionRoomRatio   As long   ' relative occlusion control for room effect
    OcclusionDirectRatio As long   ' relative occlusion control for direct path
    Exclusion            As Long     ' main exlusion control (attenuation at high frequencies)
    ExclusionLFRatio     As long   ' exclusion low-frequency level re. main control
    OutsideVolumeHF      As Long     ' outside sound cone level at high frequencies
    DopplerFactor        As long   ' like DS3D flDopplerFactor but per source
    RolloffFactor        As long   ' like DS3D flRolloffFactor but per source
    RoomRolloffFactor    As long   ' like DS3D flRolloffFactor but for room effect
    AirAbsorptionFactor  As long   ' multiplies AirAbsorptionHF member of FSOUND_REVERB_PROPERTIES
    flags                As Long     ' modifies the behavior of properties
End Type


' FSOUND_REVERB_CHANNELFLAGS
' Values for the Flags member of the FSOUND_REVERB_CHANNELPROPERTIES structure.
'
  'FSOUND_REVERB_CHANNELFLAGS
    Const FSOUND_REVERB_CHANNELFLAGS_DIRECTHFAUTO = &H1   ' Automatic setting of Direct due to distance from listener
    Const FSOUND_REVERB_CHANNELFLAGS_ROOMAUTO = &H2       ' Automatic setting of Room due to distance from listener
    Const FSOUND_REVERB_CHANNELFLAGS_ROOMHFAUTO = &H4     ' Automatic setting of RoomHF due to distance from listener
    Const FSOUND_REVERB_CHANNELFLAGS_DEFAULT = FSOUND_REVERB_CHANNELFLAGS_DIRECTHFAUTO Or FSOUND_REVERB_CHANNELFLAGS_ROOMAUTO Or FSOUND_REVERB_CHANNELFLAGS_ROOMHFAUTO



' FSOUND_FX_MODES
' These values are used with FSOUND_FX_Enable to enable DirectX 8 FX for a channel.
'
  'Enum FSOUND_FX_MODES
    'FSOUND_FX_CHORUS
    'FSOUND_FX_COMPRESSOR
    'FSOUND_FX_DISTORTION
    'FSOUND_FX_ECHO
    'FSOUND_FX_FLANGER
    'FSOUND_FX_GARGLE
    'FSOUND_FX_I3DL2REVERB
    'FSOUND_FX_PARAMEQ
    'FSOUND_FX_WAVES_REVERB
'End Enum


'FSOUND_SPEAKERMODES
'These are speaker types defined for use with the FSOUND_SetSpeakerMode command.
'Note - Only reliably works with FSOUND_OUTPUT_DSOUND or FSOUND_OUTPUT_XBOX output modes.  Other output modes will only
'interpret FSOUND_SPEAKERMODE_MONO and set everything else to be stereo.
'Using either DolbyDigital or DTS will use whatever 5.1 digital mode is available if destination hardware is unsure.
'
  'Enum FSOUND_SPEAKERMODES
    'FSOUND_SPEAKERMODE_DOLBYDIGITAL  ' The audio is played through a speaker arrangement of surround speakers with a subwoofer.
    'FSOUND_SPEAKERMODE_HEADPHONE     ' The speakers are headphones.
    'FSOUND_SPEAKERMODE_MONO          ' The speakers are monaural.
    'FSOUND_SPEAKERMODE_QUAD          ' The speakers are quadraphonic.
    'FSOUND_SPEAKERMODE_STEREO        ' The speakers are stereo (default value).
    'FSOUND_SPEAKERMODE_SURROUND      ' The speakers are surround sound.
    'FSOUND_SPEAKERMODE_DTS           ' The audio is played through a speaker arrangement of surround speakers with a subwoofer.
    'FSOUND_SPEAKERMODE_PROLOGIC2     ' Dolby Prologic 2.  Playstation 2 and Gamecube only
'End Enum


' FSOUND_INIT_FLAGS
' Initialization flags.  Use them with FSOUND_Init in the flags parameter to change various behaviour.
' FSOUND_INIT_ENABLEOUTPUTFX Is an init mode which enables the FSOUND mixer buffer to be affected by DirectX 8 effects.
' Note that due to limitations of DirectSound, FSOUND_Init may fail if this is enabled because the buffersize is too small.
' This can be fixed with FSOUND_SetBufferSize.  Increase the BufferSize until it works.
' When it is enabled you can use the FSOUND_FX api, and use FSOUND_SYSTEMCHANNEL as the channel id when setting parameters.
'
  'FSOUND_INITMODES
    Const FSOUND_INIT_USEDEFAULTMIDISYNTH = &H1       'Causes MIDI playback to force software decoding.
    Const FSOUND_INIT_GLOBALFOCUS = &H2               'For DirectSound output - sound is not muted when window is out of focus.
    Const FSOUND_INIT_ENABLEOUTPUTFX = &H4            'For DirectSound output - Allows FSOUND_FX api to be used on global software mixer output!
    Const FSOUND_INIT_ACCURATEVULEVELS = &H8          'This latency adjusts FSOUND_GetCurrentLevels, but incurs a small cpu and memory hit
    'Const FSOUND_INIT_PS2_DISABLECORE0REVERB = &H10   'PS2 only - Disable reverb on CORE 0 to regain SRAM
    'Const FSOUND_INIT_PS2_DISABLECORE1REVERB = &H20   'PS2 only - Disable reverb on CORE 1 to regain SRAM
    'Const FSOUND_INIT_PS2_SWAPDMACORES = &H40         'PS2 only - By default FMOD uses DMA CH0 for mixing, CH1 for uploads, this flag swaps them around
    Const FSOUND_INIT_DONTLATENCYADJUST = &H80        'Callbacks are not latency adjusted, and are called at mix time.  Also information functions are immediate
    'Const FSOUND_INIT_GC_INITLIBS = &H100             'Gamecube only - Initializes GC audio libraries
    Const FSOUND_INIT_STREAM_FROM_MAIN_THREAD = &H200 'Turns off fmod streamer thread, and makes streaming update from FSOUND_Update called by the user



' FSOUND_STREAM_NET_STATUS
' Status values for internet streams. Use FSOUND_Stream_Net_GetStatus to get the current status of an internet stream.
'
  'Enum FSOUND_STREAM_NET_STATUS
    'FSOUND_STREAM_NET_NOTCONNECTED         ' Stream hasn't connected yet
    'FSOUND_STREAM_NET_CONNECTING           ' Stream is connecting to remote host
    'FSOUND_STREAM_NET_BUFFERING            ' Stream is buffering data
    'FSOUND_STREAM_NET_READY                ' Stream is ready to play
    'FSOUND_STREAM_NET_ERROR                ' Stream has suffered a fatal error
'End Enum


' FSOUND_TAGFIELD_TYPE
' Describes the type of a particular tag field.
' See FSOUND_Stream_GetNumTagFields, FSOUND_Stream_GetTagField, FSOUND_Stream_FindTagField
'
 'FSOUND_TAGFIELD_TYPE
    Const FSOUND_TAGFIELD_VORBISCOMMENT = 0     ' A vorbis comment
    'FSOUND_TAGFIELD_ID3V1                 ' Part of an ID3v1 tag
    'FSOUND_TAGFIELD_ID3V2                 ' An ID3v2 frame
    'FSOUND_TAGFIELD_SHOUTCAST             ' A SHOUTcast header line
    'FSOUND_TAGFIELD_ICECAST               ' An Icecast header line
    'FSOUND_TAGFIELD_ASF                   ' An Advanced Streaming Format header line



' FSOUND_STATUS_FLAGS
' These values describe the protocol and format of an internet stream. Use FSOUND_Stream_Net_GetStatus to retrieve this information for an open internet stream.
'
  'FSOUND_STATUS_FLAGS
    Const FSOUND_PROTOCOL_SHOUTCAST = &H1
    Const FSOUND_PROTOCOL_ICECAST = &H2
    Const FSOUND_PROTOCOL_HTTP = &H4
    Const FSOUND_FORMAT_MPEG = &H10000
    Const FSOUND_FORMAT_OGGVORBIS = &H20000



'/* ================================== */
'/* Initialization / Global functions. */
'/* ================================== */


' PRE - FSOUND_Init functions. These cant be called after FSOUND_Init is
' called (they will fail). They set up FMOD system functionality.


  Declare Function FSOUND_SetOutput Lib "fmod.dll" Alias "_FSOUND_SetOutput@4" (outputtype As long) As long
  Declare Function FSOUND_SetDriver Lib "fmod.dll" Alias "_FSOUND_SetDriver@4" (driver As Long) As long
  Declare Function FSOUND_SetMixer Lib "fmod.dll" Alias "_FSOUND_SetMixer@4" (mixer As long) As long
  Declare Function FSOUND_SetBufferSize Lib "fmod.dll" Alias "_FSOUND_SetBufferSize@4" (lenms As Long) As long
  Declare Function FSOUND_SetHWND Lib "fmod.dll" Alias "_FSOUND_SetHWND@4" (hwnd As Long) As long
  Declare Function FSOUND_SetMinHardwareChannels Lib "fmod.dll" Alias "_FSOUND_SetMinHardwareChannels@4" (min As Integer) As long
  Declare Function FSOUND_SetMaxHardwareChannels Lib "fmod.dll" Alias "_FSOUND_SetMaxHardwareChannels@4" (min As Integer) As long
  Declare Function FSOUND_SetMemorySystem Lib "fmod.dll" Alias "_FSOUND_SetMemorySystem@20" (pool As Long, poollen As Long, useralloc As Long,   userrealloc As Long,   userfree As Long) As long

'
'   Main initialization / closedown functions.
'   Note : Use FSOUND_INIT_USEDEFAULTMIDISYNTH with FSOUND_Init for software override
'          with MIDI playback.
'        : Use FSOUND_INIT_GLOBALFOCUS with FSOUND_Init to make sound audible no matter
'          which window is in focus. (FSOUND_OUTPUT_DSOUND only)
'

  Declare Function FSOUND_Init Lib "fmod.dll" Alias "_FSOUND_Init@12" (mixrate As Long, maxchannels As Long, flags As long) As long
  Declare Function FSOUND_Close Lib "fmod.dll" Alias "_FSOUND_Close@0" As Long

'
'   Runtime system level functions
'

  Declare Function FSOUND_Update Lib "fmod.dll" Alias "_FSOUND_Update@0" As Long

  Declare Function FSOUND_SetSpeakerMode Lib "fmod.dll" Alias "_FSOUND_SetSpeakerMode@4" (  speakermode As long) As Long
  Declare Function FSOUND_SetSFXMasterVolume Lib "fmod.dll" Alias "_FSOUND_SetSFXMasterVolume@4" (volume As Long) As Long
  Declare Function FSOUND_SetPanSeperation Lib "fmod.dll" Alias "_FSOUND_SetPanSeperation@4" (pansep As long) As Long
  Declare Function FSOUND_File_SetCallbacks Lib "fmod.dll" Alias "_FSOUND_File_SetCallbacks@20" (OpenCallback As Long, CloseCallback As Long, ReadCallback As Long, SeekCallback As Long, TellCallback As Long) As Long

'
' System information functions.
'

  Declare Function FSOUND_GetError Lib "fmod.dll" Alias "_FSOUND_GetError@0"  As long
  Declare Function FSOUND_GetVersion Lib "fmod.dll" Alias "_FSOUND_GetVersion@0"  As long
  Declare Function FSOUND_GetOutput Lib "fmod.dll" Alias "_FSOUND_GetOutput@0"  As long
  Declare Function FSOUND_GetOutputHandle Lib "fmod.dll" Alias "_FSOUND_GetOutputHandle@0"  As Long
  Declare Function FSOUND_GetDriver Lib "fmod.dll" Alias "_FSOUND_GetDriver@0"  As Long
  Declare Function FSOUND_GetMixer Lib "fmod.dll" Alias "_FSOUND_GetMixer@0"  As long
  Declare Function FSOUND_GetNumDrivers Lib "fmod.dll" Alias "_FSOUND_GetNumDrivers@0"  As Long
  Declare Function FSOUND_GetDriverName Lib "fmod.dll" Alias "_FSOUND_GetDriverName@4" (id As Long) As Long
  Declare Function FSOUND_GetDriverCaps Lib "fmod.dll" Alias "_FSOUND_GetDriverCaps@8" (id As Long, ByRef caps As Long) As long
  Declare Function FSOUND_GetOutputRate Lib "fmod.dll" Alias "_FSOUND_GetOutputRate@0"  As Long
  Declare Function FSOUND_GetMaxChannels Lib "fmod.dll" Alias "_FSOUND_GetMaxChannels@0"  As Long
  Declare Function FSOUND_GetMaxSamples Lib "fmod.dll" Alias "_FSOUND_GetMaxSamples@0"  As Long
  Declare Function FSOUND_GetSFXMasterVolume Lib "fmod.dll" Alias "_FSOUND_GetSFXMasterVolume@0"  As Long
  Declare Function FSOUND_GetNumHardwareChannels Lib "fmod.dll" Alias "_FSOUND_GetNumHardwareChannels@0"  As Long
  Declare Function FSOUND_GetChannelsPlaying Lib "fmod.dll" Alias "_FSOUND_GetChannelsPlaying@0"  As Long
  Declare Function FSOUND_GetCPUUsage Lib "fmod.dll" Alias "_FSOUND_GetCPUUsage@0"  As Long
  Declare Sub FSOUND_GetMemoryStats Lib "fmod.dll" Alias "_FSOUND_GetMemoryStats@8" (ByRef currentalloced As Long, ByRef maxalloced As Long)

'/* =================================== */
'/* Sample management / load functions. */
'/* =================================== */


'   Sample creation and management functions
'   Note : Use FSOUND_LOADMEMORY   flag with FSOUND_Sample_Load to load from memory.
'          Use FSOUND_LOADRAW      flag with FSOUND_Sample_Load to treat as as raw pcm data.


  Declare Function FSOUND_Sample_Load Lib "fmod.dll" Alias "_FSOUND_Sample_Load@20" (index As Long, name As String, mode As long, offset As Long, length As Long) As Long
  Declare Function FSOUND_Sample_Alloc Lib "fmod.dll" Alias "_FSOUND_Sample_Alloc@28" (index As Long, length As Long, mode As Long, deffreq As Long, defvol As Long, defpan As Long, defpri As Long) As Long
  Declare Function FSOUND_Sample_Free Lib "fmod.dll" Alias "_FSOUND_Sample_Free@4" (sptr As Long) As Long
  Declare Function FSOUND_Sample_Upload Lib "fmod.dll" Alias "_FSOUND_Sample_Upload@12" (sptr As Long, ByRef srcdata As Long, mode As Long) As long
  Declare Function FSOUND_Sample_Lock Lib "fmod.dll" Alias "_FSOUND_Sample_Lock@28" (sptr As Long, offset As Long, length As Long, ByRef ptr1 As Long, ByRef ptr2 As Long, ByRef len1 As Long, ByRef len2 As Long) As long
  Declare Function FSOUND_Sample_Unlock Lib "fmod.dll" Alias "_FSOUND_Sample_Unlock@20" (sptr As Long, sptr1 As Long, sptr2 As Long, len1 As Long, len2 As Long) As long


'   Sample control functions


  Declare Function FSOUND_Sample_SetMode Lib "fmod.dll" Alias "_FSOUND_Sample_SetMode@8" (sptr As Long, mode As long) As long
  Declare Function FSOUND_Sample_SetLoopPoints Lib "fmod.dll" Alias "_FSOUND_Sample_SetLoopPoints@12" (sptr As Long, loopstart As Long, loopend As Long) As long
  Declare Function FSOUND_Sample_SetDefaults Lib "fmod.dll" Alias "_FSOUND_Sample_SetDefaults@20" (sptr As Long, deffreq As Long, defvol As Long, defpan As Long, defpri As Long) As long
  Declare Function FSOUND_Sample_SetMinMaxDistance Lib "fmod.dll" Alias "_FSOUND_Sample_SetMinMaxDistance@12" (sptr As Long, min As long, max As long) As long
  Declare Function FSOUND_Sample_SetMaxPlaybacks Lib "fmod.dll" Alias "_FSOUND_Sample_SetMaxPlaybacks@8" (sptr As Long, max As Long) As long


'   Sample information functions


  Declare Function FSOUND_Sample_Get Lib "fmod.dll" Alias "_FSOUND_Sample_Get@4" (sampno As Long) As Long
  Declare Function FSOUND_Sample_GetName Lib "fmod.dll" Alias "_FSOUND_Sample_GetName@4" (sptr As Long) As Long
  Declare Function FSOUND_Sample_GetLength Lib "fmod.dll" Alias "_FSOUND_Sample_GetLength@4" (sptr As Long) As Long
  Declare Function FSOUND_Sample_GetLoopPoints Lib "fmod.dll" Alias "_FSOUND_Sample_GetLoopPoints@12" (sptr As Long, ByRef loopstart As Long, ByRef loopend As Long) As long
  Declare Function FSOUND_Sample_GetDefaults Lib "fmod.dll" Alias "_FSOUND_Sample_GetDefaults@20" (sptr As Long, ByRef deffreq As Long, ByRef defvol As Long, ByRef defpan As Long, ByRef defpri As Long) As long
  Declare Function FSOUND_Sample_GetMode Lib "fmod.dll" Alias "_FSOUND_Sample_GetMode@4" (sptr As Long) As Long

'/* ============================ */
'/* Channel control functions.   */
'/* ============================ */


'   Playing and stopping sounds.
'   Note : Use FSOUND_FREE as the channel variable, to let FMOD pick a free channel for you.
'          Use FSOUND_ALL as the channel variable to control ALL channels with one function call!


  Declare Function FSOUND_PlaySound Lib "fmod.dll" Alias "_FSOUND_PlaySound@8" (channel As Long, sptr As Long) As Long
  Declare Function FSOUND_PlaySoundEx Lib "fmod.dll" Alias "_FSOUND_PlaySoundEx@16" (channel As Long, sptr As Long, dsp As Long, startpaused As long) As Long
  Declare Function FSOUND_StopSound Lib "fmod.dll" Alias "_FSOUND_StopSound@4" (channel As Long) As long


'   Functions to control playback of a channel.
'   Note : FSOUND_ALL can be used on most of these functions as a channel value.


  Declare Function FSOUND_SetFrequency Lib "fmod.dll" Alias "_FSOUND_SetFrequency@8" (channel As Long, freq As Long) As long
  Declare Function FSOUND_SetVolume Lib "fmod.dll" Alias "_FSOUND_SetVolume@8" (channel As Long,   Vol As Long) As long
  Declare Function FSOUND_SetVolumeAbsolute Lib "fmod.dll" Alias "_FSOUND_SetVolumeAbsolute@8" (channel As Long, Vol As Long) As long
  Declare Function FSOUND_SetPan Lib "fmod.dll" Alias "_FSOUND_SetPan@8" (channel As Long, pan As Long) As long
  Declare Function FSOUND_SetSurround Lib "fmod.dll" Alias "_FSOUND_SetSurround@8" (channel As Long, surround As Long) As long
  Declare Function FSOUND_SetMute Lib "fmod.dll" Alias "_FSOUND_SetMute@8" (channel As Long, mute As long) As long
  Declare Function FSOUND_SetPriority Lib "fmod.dll" Alias "_FSOUND_SetPriority@8" (channel As Long, Priority As Long) As long
  Declare Function FSOUND_SetReserved Lib "fmod.dll" Alias "_FSOUND_SetReserved@8" (channel As Long, reserved As Long) As long
  Declare Function FSOUND_SetPaused Lib "fmod.dll" Alias "_FSOUND_SetPaused@8" (channel As Long, Paused As long) As long
  Declare Function FSOUND_SetLoopMode Lib "fmod.dll" Alias "_FSOUND_SetLoopMode@8" (channel As Long, loopmode As Long) As long
  Declare Function FSOUND_SetCurrentPosition Lib "fmod.dll" Alias "_FSOUND_SetCurrentPosition@8" (channel As Long, offset As Long) As long

'
'   Channel information functions.
'

  Declare Function FSOUND_IsPlaying Lib "fmod.dll" Alias "_FSOUND_IsPlaying@4" (channel As Long) As long
  Declare Function FSOUND_GetFrequency Lib "fmod.dll" Alias "_FSOUND_GetFrequency@4" (channel As Long) As Long
  Declare Function FSOUND_GetVolume Lib "fmod.dll" Alias "_FSOUND_GetVolume@4" (channel As Long) As Long
  Declare Function FSOUND_GetPan Lib "fmod.dll" Alias "_FSOUND_GetPan@4" (channel As Long) As Long
  Declare Function FSOUND_GetSurround Lib "fmod.dll" Alias "_FSOUND_GetSurround@4" (channel As Long) As long
  Declare Function FSOUND_GetMute Lib "fmod.dll" Alias "_FSOUND_GetMute@4" (channel As Long) As long
  Declare Function FSOUND_GetPriority Lib "fmod.dll" Alias "_FSOUND_GetPriority@4" (channel As Long) As Long
  Declare Function FSOUND_GetReserved Lib "fmod.dll" Alias "_FSOUND_GetReserved@4" (channel As Long) As long
  Declare Function FSOUND_GetPaused Lib "fmod.dll" Alias "_FSOUND_GetPaused@4" (channel As Long) As long
  Declare Function FSOUND_GetLoopMode Lib "fmod.dll" Alias "_FSOUND_GetLoopMode@4" (channel As Long) As Long
  Declare Function FSOUND_GetCurrentPosition Lib "fmod.dll" Alias "_FSOUND_GetCurrentPosition@4" (channel As Long) As Long
  Declare Function FSOUND_GetCurrentSample Lib "fmod.dll" Alias "_FSOUND_GetCurrentSample@4" (channel As Long) As Long
  Declare Function FSOUND_GetCurrentLevels Lib "fmod.dll" Alias "_FSOUND_GetCurrentLevels@12" (channel As Long, ByRef l As Long, ByRef r As Long) As long
  Declare Function FSOUND_GetNumSubChannels Lib "fmod.dll" Alias "_FSOUND_GetNumSubChannels@4" (channel As Long) As Long
  Declare Function FSOUND_GetSubChannel Lib "fmod.dll" Alias "_FSOUND_GetSubChannel@8" (channel As Long, subchannel As Long) As Long


'/* =================== */
'/* FX functions.       */
'/* =================== */

 
'   Functions to control DX8 only effects processing.
'
'   - FX enabled samples can only be played once at a time, not multiple times at once.
'   - Sounds have to be created with FSOUND_HW2D or FSOUND_HW3D for this to work.
'   - FSOUND_INIT_ENABLEOUTPUTFX can be used to apply hardware effect processing to the
'     global mixed output of FMODs software channels.
'   - FSOUND_FX_Enable returns an FX handle that you can use to alter fx parameters.
'   - FSOUND_FX_Enable can be called multiple times in a row, even on the same FX type,
'     it will return a unique handle for each FX.
'   - FSOUND_FX_Enable cannot be called if the sound is playing or locked.
'   - FSOUND_FX_Disable must be called to reset/clear the FX from a channel.


  Declare Function FSOUND_FX_Enable Lib "fmod.dll" Alias "_FSOUND_FX_Enable@8" (channel As Long, fx As long) As Long
  Declare Function FSOUND_FX_Disable Lib "fmod.dll" Alias "_FSOUND_FX_Disable@4" (channel As Long) As long

  Declare Function FSOUND_FX_SetChorus Lib "fmod.dll" Alias "_FSOUND_FX_SetChorus@32" (fxid As Long, WetDryMix As long, Depth As long, Feedback As long, Frequency As long, Waveform As Long, Delay As long, Phase As Long) As long
  Declare Function FSOUND_FX_SetCompressor Lib "fmod.dll" Alias "_FSOUND_FX_SetCompressor@28" (fxid As Long, Gain As long, Attack As long, Release As long, Threshold As long, Ratio As long, Predelay As long) As long
  Declare Function FSOUND_FX_SetDistortion Lib "fmod.dll" Alias "_FSOUND_FX_SetDistortion@24" (fxid As Long, Gain As long, Edge As long, PostEQCenterFrequency As long, PostEQBandwidth As long, PreLowpassCutoff As long) As long
  Declare Function FSOUND_FX_SetEcho Lib "fmod.dll" Alias "_FSOUND_FX_SetEcho@24" (fxid As Long, WetDryMix As long, Feedback As long, LeftDelay As long, RightDelay As long, PanDelay As Long) As long
  Declare Function FSOUND_FX_SetFlanger Lib "fmod.dll" Alias "_FSOUND_FX_SetFlanger@32" (fxid As Long, WetDryMix As long, Depth As long, Feedback As long, Frequency As long, Waveform As Long, Delay As long, Phase As Long) As long
  Declare Function FSOUND_FX_SetGargle Lib "fmod.dll" Alias "_FSOUND_FX_SetGargle@12" (fxid As Long, RateHz As Long, WaveShape As Long) As long
  Declare Function FSOUND_FX_SetI3DL2Reverb Lib "fmod.dll" Alias "_FSOUND_FX_SetI3DL2Reverb@52" (fxid As Long, Room As Long, RoomHF As Long, RoomRolloffFactor As long, DecayTime As long, DecayHFRatio As long, Reflections As Long, ReflectionsDelay As long,   Reverb As Long,   ReverbDelay As long,   Diffusion As long,   Density As long,   HFReference As long) As long
  Declare Function FSOUND_FX_SetParamEQ Lib "fmod.dll" Alias "_FSOUND_FX_SetParamEQ@16" (fxid As Long, Center As long, Bandwidth As long, Gain As long) As long
  Declare Function FSOUND_FX_SetWavesReverb Lib "fmod.dll" Alias "_FSOUND_FX_SetWavesReverb@20" (fxid As Long, InGain As long, ReverbMix As long, ReverbTime As long, HighFreqRTRatio As long) As long

'/* =================== */
'/* 3D sound functions. */
'/* =================== */

  Declare Function FSOUND_3D_SetDopplerFactor Lib "fmod.dll" Alias "_FSOUND_3D_SetDopplerFactor@4" (fscale As long) As Long
  Declare Function FSOUND_3D_SetDistanceFactor Lib "fmod.dll" Alias "_FSOUND_3D_SetDistanceFactor@4" (fscale As long) As Long
  Declare Function FSOUND_3D_SetRolloffFactor Lib "fmod.dll" Alias "_FSOUND_3D_SetRolloffFactor@4" (fscale As long) As Long
  Declare Function FSOUND_3D_SetAttributes Lib "fmod.dll" Alias "_FSOUND_3D_SetAttributes@12" (channel As Long, ByRef Pos As long, ByRef vel As long) As long
  Declare Function FSOUND_3D_GetAttributes Lib "fmod.dll" Alias "_FSOUND_3D_GetAttributes@12" (channel As Long, ByRef Pos As long, ByRef vel As long) As long

  Declare Function FSOUND_3D_Listener_SetCurrent Lib "fmod.dll" Alias "_FSOUND_3D_Listener_SetCurrent@8" (current As Long) As Long
  Declare Function FSOUND_3D_Listener_SetAttributes Lib "fmod.dll" Alias "_FSOUND_3D_Listener_SetAttributes@32" (Pos As long, vel As long, fx As long, fy As long, fz As long, tx As long, ty As long, tz As long) As Long
  Declare Function FSOUND_3D_Listener_GetAttributes Lib "fmod.dll" Alias "_FSOUND_3D_Listener_GetAttributes@32" (ByRef Pos As long, ByRef vel As long, ByRef fx As long, ByRef fy As long, ByRef fz As long, ByRef tx As long, ByRef ty As long, ByRef tz As long) As Long

' ========================= */
' File Streaming functions. */
' ========================= */

'
'    Note : Use FSOUND_LOADMEMORY   flag with FSOUND_Stream_Open to stream from memory.
'           Use FSOUND_LOADRAW      flag with FSOUND_Stream_Open to treat stream as raw pcm data.
'           Use FSOUND_MPEGACCURATE flag with FSOUND_Stream_Open to open mpegs in 'accurate mode' for settime/gettime/getlengthms.
'           Use FSOUND_FREE as the 'channel' variable, to let FMOD pick a free channel for you.
'

  Declare Function FSOUND_Stream_SetBufferSize Lib "fmod.dll" Alias "_FSOUND_Stream_SetBufferSize@4" (  ms As Long) As long

  Declare Function FSOUND_Stream_Open Lib "fmod.dll" Alias "_FSOUND_Stream_Open@16" (filename As String, mode As long, offset As Long, length As Long) As Long
  Declare Function FSOUND_Stream_Open2 Lib "fmod.dll" Alias "_FSOUND_Stream_Open@16" (ByRef data As long, mode As long, offset As Long, length As Long) As Long
  Declare Function FSOUND_Stream_Create Lib "fmod.dll" Alias "_FSOUND_Stream_Create@20" (callback As Long, length As Long, mode As Long, samplerate As Long, userdata As Long) As Long
  Declare Function FSOUND_Stream_Close Lib "fmod.dll" Alias "_FSOUND_Stream_Close@4" (stream As Long) As long

  Declare Function FSOUND_Stream_Play Lib "fmod.dll" Alias "_FSOUND_Stream_Play@8"  (channel As Long, stream As Long) As Long
  Declare Function FSOUND_Stream_PlayEx Lib "fmod.dll" Alias "_FSOUND_Stream_PlayEx@16" (channel As Long, stream As Long, dsp As Long, startpaused As long) As Long
  Declare Function FSOUND_Stream_Stop Lib "fmod.dll" Alias "_FSOUND_Stream_Stop@4" (stream As Long) As long

  Declare Function FSOUND_Stream_SetPosition Lib "fmod.dll" Alias "_FSOUND_Stream_SetPosition@8" (stream As Long, positition As Long) As long
  Declare Function FSOUND_Stream_GetPosition Lib "fmod.dll" Alias "_FSOUND_Stream_GetPosition@4" (stream As Long) As Long
  Declare Function FSOUND_Stream_SetTime Lib "fmod.dll" Alias "_FSOUND_Stream_SetTime@8" (stream As Long, ms As Long) As long
  Declare Function FSOUND_Stream_GetTime Lib "fmod.dll" Alias "_FSOUND_Stream_GetTime@4" (stream As Long) As Long
  Declare Function FSOUND_Stream_GetLength Lib "fmod.dll" Alias "_FSOUND_Stream_GetLength@4" (stream As Long) As Long
  Declare Function FSOUND_Stream_GetLengthMs Lib "fmod.dll" Alias "_FSOUND_Stream_GetLengthMs@4" (stream As Long) As Long

  Declare Function FSOUND_Stream_SetMode Lib "fmod.dll" Alias "_FSOUND_Stream_SetMode@8" (stream As Long, mode As Long) As long
  Declare Function FSOUND_Stream_GetMode Lib "fmod.dll" Alias "_FSOUND_Stream_GetMode@4" (stream As Long) As Long
  Declare Function FSOUND_Stream_SetLoopPoints Lib "fmod.dll" Alias "_FSOUND_Stream_SetLoopPoints@12" (stream As Long, loopstartpcm As Long, loopendpcm As Long) As long
  Declare Function FSOUND_Stream_SetLoopCount Lib "fmod.dll" Alias "_FSOUND_Stream_SetLoopCount@8" (stream As Long, count As Long) As long
  Declare Function FSOUND_Stream_GetOpenState Lib "fmod.dll" Alias "_FSOUND_Stream_GetOpenState@4" (stream As Long) As Long
  Declare Function FSOUND_Stream_GetSample Lib "fmod.dll" Alias "_FSOUND_Stream_GetSample@4" (stream As Long) As Long
  Declare Function FSOUND_Stream_CreateDSP Lib "fmod.dll" Alias "_FSOUND_Stream_CreateDSP@16" (stream As Long, callback As Long, Priority As Long, userdata As Long) As Long

  Declare Function FSOUND_Stream_SetEndCallback Lib "fmod.dll" Alias "_FSOUND_Stream_SetEndCallback@12" (stream As Long, callback As Long, userdata As Long) As long
  Declare Function FSOUND_Stream_SetSyncCallback Lib "fmod.dll" Alias "_FSOUND_Stream_SetSyncCallback@12" (stream As Long, callback As Long, userdata As Long) As long

  Declare Function FSOUND_Stream_AddSyncPoint Lib "fmod.dll" Alias "_FSOUND_Stream_AddSyncPoint@12" (stream As Long, pcmoffset As Long, name As String) As Long
  Declare Function FSOUND_Stream_DeleteSyncPoint Lib "fmod.dll" Alias "_FSOUND_Stream_DeleteSyncPoint@4" (point As Long) As long
  Declare Function FSOUND_Stream_GetNumSyncPoints Lib "fmod.dll" Alias "_FSOUND_Stream_GetNumSyncPoints@4" (stream As Long) As Long
  Declare Function FSOUND_Stream_GetSyncPoint Lib "fmod.dll" Alias "_FSOUND_Stream_GetSyncPoint@8" (stream As Long, index As Long) As Long
  Declare Function FSOUND_Stream_GetSyncPointInfo Lib "fmod.dll" Alias "_FSOUND_Stream_GetSyncPointInfo@8" (point As Long, ByRef pcmoffset As Long) As Long

  Declare Function FSOUND_Stream_SetSubStream Lib "fmod.dll" Alias "_FSOUND_Stream_SetSubStream@8" (stream As Long, index As Long) As long
  Declare Function FSOUND_Stream_GetNumSubStreams Lib "fmod.dll" Alias "_FSOUND_Stream_GetNumSubStreams@4" (stream As Long) As Long
  Declare Function FSOUND_Stream_SetSubStreamSentence Lib "fmod.dll" Alias "_FSOUND_Stream_SetSubStreamSentence@12" (stream As Long, ByRef sentencelist As Long, numitems As Long) As long

  Declare Function FSOUND_Stream_GetNumTagFields Lib "fmod.dll" Alias "_FSOUND_Stream_GetNumTagFields@8" (stream As Long, ByRef num As Long) As long
  Declare Function FSOUND_Stream_GetTagField Lib "fmod.dll" Alias "_FSOUND_Stream_GetTagField@24" (stream As Long, num As Long, ByRef tagtype As Long, ByRef name As String, ByRef value As Long, ByRef length As Long) As long
  Declare Function FSOUND_Stream_FindTagField Lib "fmod.dll" Alias "_FSOUND_Stream_FindTagField@20" (stream As Long, tagtype As Long, name As String, ByRef value As Long, ByRef length As Long) As long

'
'   Internet streaming functions
'

  Declare Function FSOUND_Stream_Net_SetProxy Lib "fmod.dll" Alias "_FSOUND_Stream_Net_SetProxy@4" (proxy As String) As long
  Declare Function FSOUND_Stream_Net_GetLastServerStatus Lib "fmod.dll" Alias "_FSOUND_Stream_Net_GetLastServerStatus@0"  As Long
  Declare Function FSOUND_Stream_Net_SetBufferProperties Lib "fmod.dll" Alias "_FSOUND_Stream_Net_SetBufferProperties@12" (buffersize As Long, prebuffer_percent As Long, rebuffer_percent As Long) As long
  Declare Function FSOUND_Stream_Net_GetBufferProperties Lib "fmod.dll" Alias "_FSOUND_Stream_Net_GetBufferProperties@12" (ByRef buffersize As Long, ByRef prebuffer_percent As Long, ByRef rebuffer_percent As Long) As long
  Declare Function FSOUND_Stream_Net_SetMetadataCallback Lib "fmod.dll" Alias "_FSOUND_Stream_Net_SetMetadataCallback@12" (stream As Long, callback As Long, userdata As Long) As long
  Declare Function FSOUND_Stream_Net_GetStatus Lib "fmod.dll" Alias "_FSOUND_Stream_Net_GetStatus@20" (stream As Long, ByRef status As Long, ByRef bufferpercentused As Long, ByRef bitrate As Long, ByRef flags As Long) As long

'/* =================== */
'/* CD audio functions. */
'/* =================== */


'   Note : 0 = default cdrom.  Otherwise specify the drive letter, for example. 'D'.


  Declare Function FSOUND_CD_Play Lib "fmod.dll" Alias "_FSOUND_CD_Play@8" (drive As long, Track As Long) As long
  Declare Function FSOUND_CD_SetPlayMode Lib "fmod.dll" Alias "_FSOUND_CD_SetPlayMode@8" (drive As long, mode As long) As Long
  Declare Function FSOUND_CD_Stop Lib "fmod.dll" Alias "_FSOUND_CD_Stop@4" (drive As long) As long
  Declare Function FSOUND_CD_SetPaused Lib "fmod.dll" Alias "_FSOUND_CD_SetPaused@8" (drive As long, Paused As long) As long
  Declare Function FSOUND_CD_SetVolume Lib "fmod.dll" Alias "_FSOUND_CD_SetVolume@8" (drive As long, volume As Long) As long
  Declare Function FSOUND_CD_SetTrackTime Lib "fmod.dll" Alias "_FSOUND_CD_SetTrackTime@8" (drive As long,   ms As Long) As long
  Declare Function FSOUND_CD_Eject Lib "fmod.dll" Alias "_FSOUND_CD_Eject@4" (drive As long) As long

  Declare Function FSOUND_CD_GetPaused Lib "fmod.dll" Alias "_FSOUND_CD_GetPaused@4" (drive As long) As long
  Declare Function FSOUND_CD_GetTrack Lib "fmod.dll" Alias "_FSOUND_CD_GetTrack@4" (drive As long) As Long
  Declare Function FSOUND_CD_GetNumTracks Lib "fmod.dll" Alias "_FSOUND_CD_GetNumTracks@4" (drive As long) As Long
  Declare Function FSOUND_CD_GetVolume Lib "fmod.dll" Alias "_FSOUND_CD_GetVolume@4" (drive As long) As Long
  Declare Function FSOUND_CD_GetTrackLength Lib "fmod.dll" Alias "_FSOUND_CD_GetTrackLength@8" (drive As long, Track As Long) As Long
  Declare Function FSOUND_CD_GetTrackTime Lib "fmod.dll" Alias "_FSOUND_CD_GetTrackTime@4" (drive As long) As Long

'/* ============== */
'/* DSP functions. */
'/* ============== */

 
'   DSP Unit control and information functions.
'   These functions allow you access to the mixed stream that FMOD uses to play back sound on.


  Declare Function FSOUND_DSP_Create Lib "fmod.dll" Alias "_FSOUND_DSP_Create@12" (callback As Long, Priority As Long, param As Long) As Long
  Declare Function FSOUND_DSP_Free Lib "fmod.dll" Alias "_FSOUND_DSP_Free@4" (unit As Long) As Long
  Declare Function FSOUND_DSP_SetPriority Lib "fmod.dll" Alias "_FSOUND_DSP_SetPriority@8" (unit As Long, Priority As Long) As Long
  Declare Function FSOUND_DSP_GetPriority Lib "fmod.dll" Alias "_FSOUND_DSP_GetPriority@4" (unit As Long) As Long
  Declare Function FSOUND_DSP_SetActive Lib "fmod.dll" Alias "_FSOUND_DSP_SetActive@8" (unit As Long, active As Integer) As Long
  Declare Function FSOUND_DSP_GetActive Lib "fmod.dll" Alias "_FSOUND_DSP_GetActive@4" (unit As Long) As long


'   Functions to get hold of FSOUND 'system DSP unit' handles


  Declare Function FSOUND_DSP_GetClearUnit Lib "fmod.dll" Alias "_FSOUND_DSP_GetClearUnit@0"  As Long
  Declare Function FSOUND_DSP_GetSFXUnit Lib "fmod.dll" Alias "_FSOUND_DSP_GetSFXUnit@0"  As Long
  Declare Function FSOUND_DSP_GetMusicUnit Lib "fmod.dll" Alias "_FSOUND_DSP_GetMusicUnit@0"  As Long
  Declare Function FSOUND_DSP_GetFFTUnit Lib "fmod.dll" Alias "_FSOUND_DSP_GetFFTUnit@0"  As Long
  Declare Function FSOUND_DSP_GetClipAndCopyUnit Lib "fmod.dll" Alias "_FSOUND_DSP_GetClipAndCopyUnit@0"  As Long


'   Miscellaneous DSP functions
'   Note for the spectrum analysis function to work, you have to enable the FFT DSP unit with
'   the following code FSOUND_DSP_SetActive(FSOUND_DSP_GetFFTUnit(), TRUE);
'   It is off by default to save cpu usage.


  Declare Function FSOUND_DSP_MixBuffers Lib "fmod.dll" Alias "_FSOUND_DSP_MixBuffers@28" (destbuffer As Long, srcbuffer As Long, length As Long, freq As Long, Vol As Long, pan As Long, mode As Long) As long
  Declare Function FSOUND_DSP_ClearMixBuffer Lib "fmod.dll" Alias "_FSOUND_DSP_ClearMixBuffer@0"  As Long
  Declare Function FSOUND_DSP_GetBufferLength Lib "fmod.dll" Alias "_FSOUND_DSP_GetBufferLength@0"  As Long
  Declare Function FSOUND_DSP_GetBufferLengthTotal Lib "fmod.dll" Alias "_FSOUND_DSP_GetBufferLengthTotal@0"  As Long
  Declare Function FSOUND_DSP_GetSpectrum Lib "fmod.dll" Alias "_FSOUND_DSP_GetSpectrum@0"  As Long

'/* =================================================================================== */
'/* Reverb functions. (eax2/eax3 reverb)  (ONLY SUPPORTED ON WIN32 W/ FSOUND_HW3D FLAG) */
'/* =================================================================================== */


'   See top of file for definitions and information on the reverb parameters.

'The FSOUND_REVERB_PRESETS have not been included in VB yet so they cannot yet be used here...
  Declare Function FSOUND_Reverb_SetProperties Lib "fmod.dll" Alias "_FSOUND_Reverb_SetProperties@4" (ByRef prop As FSOUND_REVERB_PROPERTIES) As long
  Declare Function FSOUND_Reverb_GetProperties Lib "fmod.dll" Alias "_FSOUND_Reverb_GetProperties@4" (ByRef prop As FSOUND_REVERB_PROPERTIES) As long
  Declare Function FSOUND_Reverb_SetChannelProperties Lib "fmod.dll" Alias "_FSOUND_Reverb_SetChannelProperties@8" (channel As Long, ByRef prop as FSOUND_REVERB_CHANNELPROPERTIES) As long
  Declare Function FSOUND_Reverb_GetChannelProperties Lib "fmod.dll" Alias "_FSOUND_Reverb_GetChannelProperties@8" (channel As Long, ByRef prop as FSOUND_REVERB_CHANNELPROPERTIES) As long

'/* ===================================================== */
'/* Recording functions  (ONLY SUPPORTED IN WIN32, WINCE) */
'/* ===================================================== */


'    Recording initialization functions


  Declare Function FSOUND_Record_SetDriver Lib "fmod.dll" Alias "_FSOUND_Record_SetDriver@4" (outputtype As Long) As long
  Declare Function FSOUND_Record_GetNumDrivers Lib "fmod.dll" Alias "_FSOUND_Record_GetNumDrivers@0"  As Long
  Declare Function FSOUND_Record_GetDriverName Lib "fmod.dll" Alias "_FSOUND_Record_GetDriverName@4" (id As Long) As Long
  Declare Function FSOUND_Record_GetDriver Lib "fmod.dll" Alias "_FSOUND_Record_GetDriver@0"  As Long


'    Recording functionality.  Only one recording session will work at a time.


  Declare Function FSOUND_Record_StartSample Lib "fmod.dll" Alias "_FSOUND_Record_StartSample@8" (sample As Long, loopit As long) As long
  Declare Function FSOUND_Record_Stop Lib "fmod.dll" Alias "_FSOUND_Record_Stop@0"  As long
  Declare Function FSOUND_Record_GetPosition Lib "fmod.dll" Alias "_FSOUND_Record_GetPosition@0"  As Long

'/* ========================================================================================== */
'/* FMUSIC API (MOD,S3M,XM,IT,MIDI PLAYBACK)                                                   */
'/* ========================================================================================== */

 
'   Song management / playback functions.


  Declare Function FMUSIC_LoadSong Lib "fmod.dll" Alias "_FMUSIC_LoadSong@4" (name As String) As Long
  Declare Function FMUSIC_LoadSongEx Lib "fmod.dll" Alias "_FMUSIC_LoadSongEx@24" (name As String, offset As Long, length As Long, mode As long, ByRef sentencelist As Long, numitems As Long) As Long
  Declare Function FMUSIC_LoadSongEx2 Lib "fmod.dll" Alias "_FMUSIC_LoadSongEx@24" (ByRef data As long, offset As Long, length As Long, mode As long, ByRef sentencelist As Long, numitems As Long) As Long
  Declare Function FMUSIC_GetOpenState Lib "fmod.dll" Alias "_FMUSIC_GetOpenState@4" (module As Long) As Long

  Declare Function FMUSIC_FreeSong Lib "fmod.dll" Alias "_FMUSIC_FreeSong@4" (module As Long) As long
  Declare Function FMUSIC_PlaySong Lib "fmod.dll" Alias "_FMUSIC_PlaySong@4" (module As Long) As long
  Declare Function FMUSIC_StopSong Lib "fmod.dll" Alias "_FMUSIC_StopSong@4" (module As Long) As long
  Declare Function FMUSIC_StopAllSongs Lib "fmod.dll" Alias "_FMUSIC_StopAllSongs@0"  As Long

  Declare Function FMUSIC_SetZxxCallback Lib "fmod.dll" Alias "_FMUSIC_SetZxxCallback@8" (module As Long, callback As Long) As long
  Declare Function FMUSIC_SetRowCallback Lib "fmod.dll" Alias "_FMUSIC_SetRowCallback@12" (module As Long, callback As Long, rowstep As Long) As long
  Declare Function FMUSIC_SetOrderCallback Lib "fmod.dll" Alias "_FMUSIC_SetOrderCallback@12" (module As Long, callback As Long, rowstep As Long) As long
  Declare Function FMUSIC_SetInstCallback Lib "fmod.dll" Alias "_FMUSIC_SetInstCallback@12" (module As Long, callback As Long, instrument As Long) As long

  Declare Function FMUSIC_SetSample Lib "fmod.dll" Alias "_FMUSIC_SetSample@12" (module As Long, sampno As Long, sptr As Long) As long
  Declare Function FMUSIC_SetUserData Lib "fmod.dll" Alias "_FMUSIC_SetUserData@8" (module As Long, userdata As Long) As long
  Declare Function FMUSIC_OptimizeChannels Lib "fmod.dll" Alias "_FMUSIC_OptimizeChannels@12" (module As Long, maxchannels As Long, minvolume As Long) As long

'   Runtime song functions


  Declare Function FMUSIC_SetReverb Lib "fmod.dll" Alias "_FMUSIC_SetReverb@4" (Reverb As long) As long
  Declare Function FMUSIC_SetLooping Lib "fmod.dll" Alias "_FMUSIC_SetLooping@8" (module As Long, looping As long) As long
  Declare Function FMUSIC_SetOrder Lib "fmod.dll" Alias "_FMUSIC_SetOrder@8" (module As Long, order As Long) As long
  Declare Function FMUSIC_SetPaused Lib "fmod.dll" Alias "_FMUSIC_SetPaused@8" (module As Long, Pause As long) As long
  Declare Function FMUSIC_SetMasterVolume Lib "fmod.dll" Alias "_FMUSIC_SetMasterVolume@8" (module As Long, volume As Long) As long
  Declare Function FMUSIC_SetMasterSpeed Lib "fmod.dll" Alias "_FMUSIC_SetMasterSpeed@8" (module As Long, speed As long) As long
  Declare Function FMUSIC_SetPanSeperation Lib "fmod.dll" Alias "_FMUSIC_SetPanSeperation@8" (module As Long, pansep As long) As long


'   Static song information functions


  Declare Function FMUSIC_GetName Lib "fmod.dll" Alias "_FMUSIC_GetName@4" (module As Long) As Long
  Declare Function FMUSIC_GetType Lib "fmod.dll" Alias "_FMUSIC_GetType@4" (module As Long) As long
  Declare Function FMUSIC_GetNumOrders Lib "fmod.dll" Alias "_FMUSIC_GetNumOrders@4" (module As Long) As Long
  Declare Function FMUSIC_GetNumPatterns Lib "fmod.dll" Alias "_FMUSIC_GetNumPatterns@4" (module As Long) As Long
  Declare Function FMUSIC_GetNumInstruments Lib "fmod.dll" Alias "_FMUSIC_GetNumInstruments@4"  (module As Long) As Long
  Declare Function FMUSIC_GetNumSamples Lib "fmod.dll" Alias "_FMUSIC_GetNumSamples@4" (module As Long) As Long
  Declare Function FMUSIC_GetNumChannels Lib "fmod.dll" Alias "_FMUSIC_GetNumChannels@4" (module As Long) As Long
  Declare Function FMUSIC_GetSample Lib "fmod.dll" Alias "_FMUSIC_GetSample@8" (module As Long, sampno As Long) As Long
  Declare Function FMUSIC_GetPatternLength Lib "fmod.dll" Alias "_FMUSIC_GetPatternLength@8" (module As Long, orderno As Long) As Long


'   Runtime song information


  Declare Function FMUSIC_IsFinished Lib "fmod.dll" Alias "_FMUSIC_IsFinished@4" (module As Long) As long
  Declare Function FMUSIC_IsPlaying Lib "fmod.dll" Alias "_FMUSIC_IsPlaying@4" (module As Long) As long
  Declare Function FMUSIC_GetMasterVolume Lib "fmod.dll" Alias "_FMUSIC_GetMasterVolume@4" (module As Long) As Long
  Declare Function FMUSIC_GetGlobalVolume Lib "fmod.dll" Alias "_FMUSIC_GetGlobalVolume@4" (module As Long) As Long
  Declare Function FMUSIC_GetOrder Lib "fmod.dll" Alias "_FMUSIC_GetOrder@4" (module As Long) As Long
  Declare Function FMUSIC_GetPattern Lib "fmod.dll" Alias "_FMUSIC_GetPattern@4" (module As Long) As Long
  Declare Function FMUSIC_GetSpeed Lib "fmod.dll" Alias "_FMUSIC_GetSpeed@4" (module As Long) As Long
  Declare Function FMUSIC_GetBPM Lib "fmod.dll" Alias "_FMUSIC_GetBPM@4" (module As Long) As Long
  Declare Function FMUSIC_GetRow Lib "fmod.dll" Alias "_FMUSIC_GetRow@4" (module As Long) As Long
  Declare Function FMUSIC_GetPaused Lib "fmod.dll" Alias "_FMUSIC_GetPaused@4" (module As Long) As long
  Declare Function FMUSIC_GetTime Lib "fmod.dll" Alias "_FMUSIC_GetTime@4" (module As Long) As Long
  Declare Function FMUSIC_GetRealChannel Lib "fmod.dll" Alias "_FMUSIC_GetRealChannel@8" (module As Long, modchannel As Long) As Long
  Declare Function FMUSIC_GetUserData Lib "fmod.dll" Alias "_FMUSIC_GetUserData@4" (module As Long) As Long

'************
'* Windows Declarations (Added by Adion)
'************
'Required for GetStringFromPointer
Declare Function ConvCStringToVBString Lib "kernel32" Alias "lstrcpyA" (lpsz As String, pt As Long) As Long ' Notice the As Long return value replacing the As String given by the API Viewer.
'Required for the FFT/Spectral functions
Declare Sub CopyMemory Lib "kernel32" Alias "RtlMoveMemory" (Destination As long, Source As long, length As Long)

'************
'* FUNCTIONS (Added by Adion)
'************
'Usage: myerrorstring = FSOUND_GetErrorString(FSOUND_GetError)
  Function FSOUND_GetErrorString(  errorcode As Long) As String
    Select Case errorcode
        Case FMOD_ERR_NONE:             FSOUND_GetErrorString = "No errors"
        Case FMOD_ERR_BUSY:             FSOUND_GetErrorString = "Cannot call this command after FSOUND_Init.  Call FSOUND_Close first."
        Case FMOD_ERR_UNINITIALIZED:    FSOUND_GetErrorString = "This command failed because FSOUND_Init was not called"
        Case FMOD_ERR_PLAY:             FSOUND_GetErrorString = "Playing the sound failed."
        Case FMOD_ERR_INIT:             FSOUND_GetErrorString = "Error initializing output device."
        Case FMOD_ERR_ALLOCATED:        FSOUND_GetErrorString = "The output device is already in use and cannot be reused."
        Case FMOD_ERR_OUTPUT_FORMAT:    FSOUND_GetErrorString = "Soundcard does not support the features needed for this soundsystem (16bit stereo output)"
        Case FMOD_ERR_COOPERATIVELEVEL: FSOUND_GetErrorString = "Error setting cooperative level for hardware."
        Case FMOD_ERR_CREATEBUFFER:     FSOUND_GetErrorString = "Error creating hardware sound buffer."
        Case FMOD_ERR_FILE_NOTFOUND:    FSOUND_GetErrorString = "File not found"
        Case FMOD_ERR_FILE_FORMAT:      FSOUND_GetErrorString = "Unknown file format"
        Case FMOD_ERR_FILE_BAD:         FSOUND_GetErrorString = "Error loading file"
        Case FMOD_ERR_MEMORY:           FSOUND_GetErrorString = "Not enough memory "
        Case FMOD_ERR_VERSION:          FSOUND_GetErrorString = "The version number of this file format is not supported"
        Case FMOD_ERR_INVALID_PARAM:    FSOUND_GetErrorString = "An invalid parameter was passed to this function"
        Case FMOD_ERR_NO_EAX:           FSOUND_GetErrorString = "Tried to use an EAX command on a non EAX enabled channel or output."
        Case FMOD_ERR_CHANNEL_ALLOC:    FSOUND_GetErrorString = "Failed to allocate a new channel"
        Case FMOD_ERR_RECORD:           FSOUND_GetErrorString = "Recording is not supported on this machine"
        Case FMOD_ERR_MEDIAPLAYER:      FSOUND_GetErrorString = "Required Mediaplayer codec is not installed"
        Case FMOD_ERR_CDDEVICE:         FSOUND_GetErrorString = "An error occured trying to open the specified CD device"
        Case Else:                      FSOUND_GetErrorString = "Unknown error"
    End Select
End Function


